==> form-dinamico-react-render-0.1.2.tgz: package/es/formTransformer.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import { alloweds, isTypeHasntLabel } from './utils/elementsUtils';
import { isDateValid, toDateString, formatDateStringToISO } from './utils/dateUtils';

export var formToJSONSchema = function formToJSONSchema() {
    var form = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var schema = {
        type: 'object',
        properties: {}
    };
    var _form$elements = form.elements,
        elements = _form$elements === undefined ? [] : _form$elements;


    return elements.reduce(function (newSchema, section) {
        var elements = section.elements;

        var sectionProperties = elements.filter(function (field) {
            return alloweds.includes(field.type);
        }).reduce(function (previousFields, field) {
            var key = field.key,
                title = field.title,
                type = field.type,
                titleMap = field.titleMap;


            previousFields[key] = { title: title, type: 'string', required: [] };

            if (type === 'radios' && titleMap) {
                previousFields[key].enum = titleMap.map(function (object) {
                    return '' + object.value;
                });
                previousFields[key].enumNames = titleMap.map(function (object) {
                    return '' + object.name;
                });
            }

            if (type === 'checkboxes' && titleMap) {
                previousFields[key].type = 'array';
                previousFields[key].items = {
                    type: 'string',
                    'enum': titleMap.map(function (object) {
                        return '' + object.value;
                    }),
                    enumNames: titleMap.map(function (object) {
                        return '' + object.name;
                    })
                };
                previousFields[key].uniqueItems = true;
            }

            if (type === 'file-multiple') {
                previousFields[key].type = 'array';
                previousFields[key].items = {
                    type: 'object',
                    properties: {
                        name: { type: 'string' },
                        id: { type: 'string' },
                        type: { type: 'string' },
                        length: { type: 'number' },
                        originalFileName: { type: 'string' },
                        link: { type: 'string' },
                        displayName: { type: 'string' }
                    }
                };
            }

            if (type === 'select' && titleMap) {
                previousFields[key].items = {
                    type: 'array',
                    titleMap: titleMap
                };
            }

            if (type === 'table-editable') {
                previousFields[key].type = 'string';
                previousFields[key].elements = field.elements;
            }

            return previousFields;
        }, {});

        return _extends({}, newSchema, {
            properties: _extends({}, newSchema.properties, sectionProperties)
        });
    }, schema);
};

export var formToUISchema = function formToUISchema() {
    var form = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var environment = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var _form$elements2 = form.elements,
        elements = _form$elements2 === undefined ? [] : _form$elements2;


    return elements.reduce(function (uiSchema, section, indice) {
        var elements = section.elements;


        var schemaProperties = elements.filter(function (field) {
            return alloweds.includes(field.type);
        }).reduce(function (previousFields, field) {
            var key = field.key,
                type = field.type,
                cols = field.cols;

            var fieldProps = {};

            if (cols) {
                var _ref;

                var sectionLayoutArray = uiSchema['ui:layout'][indice] || [];
                uiSchema['ui:layout'][indice] = [].concat(sectionLayoutArray, [(_ref = {}, _ref[key] = Number(cols), _ref)]);
            }

            if (type === 'textarea') {
                fieldProps['ui:widget'] = 'textarea';
            }

            if (type === 'input-date') {
                fieldProps['ui:widget'] = 'dateWidget';
            }

            if (type === 'h1') {
                fieldProps['ui:widget'] = 'h1Widget';
            }

            if (type === 'radios') {
                fieldProps['ui:widget'] = 'radio';
            }

            if (type === 'checkboxes') {
                fieldProps['ui:widget'] = 'checkboxes';

                var uiOptions = fieldProps['ui:options'];
                fieldProps['ui:options'] = _extends({}, uiOptions, {
                    addable: false,
                    orderable: false,
                    removable: false
                });
            }

            if (type === 'file-multiple') {
                var upload = environment.upload;


                fieldProps['ui:widget'] = 'file-multiple';

                var _uiOptions = fieldProps['ui:options'];
                fieldProps['ui:options'] = _extends({}, _uiOptions, {
                    addable: false,
                    orderable: false,
                    removable: false,
                    upload: upload
                });
            }

            if (type === 'rich-text') {
                fieldProps['ui:widget'] = 'richTextWidget';
            }

            if (type === 'select') {
                fieldProps['ui:widget'] = 'select';
            }

            if (type === 'table-editable') {
                fieldProps['ui:widget'] = 'table-editable';
            }

            if (isTypeHasntLabel(type)) {
                var _uiOptions2 = fieldProps['ui:options'];
                fieldProps['ui:options'] = _extends({}, _uiOptions2, { label: false });
            }

            if (environment.customProps && environment.customProps[type]) {
                var customProps = environment.customProps[type];

                var _uiOptions3 = fieldProps['ui:options'];
                fieldProps['ui:options'] = _extends({}, _uiOptions3, {
                    customProps: customProps
                });
            }

            previousFields[key] = fieldProps;

            return previousFields;
        }, {});

        return _extends({}, uiSchema, schemaProperties);
    }, { 'ui:layout': [] });
};

export var formDefaultValues = function formDefaultValues() {
    var form = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var _form$elements3 = form.elements,
        elements = _form$elements3 === undefined ? [] : _form$elements3;


    return elements.reduce(function (newSchema, section) {
        var elements = section.elements;


        var schemaProperties = elements.reduce(function (previousFields, field) {
            var key = field.key,
                type = field.type,
                valueDefault = field.valueDefault;


            if (!valueDefault) {
                return previousFields;
            }

            var value = valueDefault;

            if (type === 'checkboxes') {
                value = valueDefault.split(',');
            }

            if (type === 'input-date') {
                value = formatDateStringToISO(valueDefault);
            }

            previousFields[key] = value;

            return previousFields;
        }, {});

        return _extends({}, newSchema, schemaProperties);
    }, {});
};

export var formDataValues = function formDataValues() {
    var formData = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var parsed = _extends({}, formData);

    for (var _iterator = Object.keys(formData), _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {
        var _ref2;

        if (_isArray) {
            if (_i >= _iterator.length) break;
            _ref2 = _iterator[_i++];
        } else {
            _i = _iterator.next();
            if (_i.done) break;
            _ref2 = _i.value;
        }

        var key = _ref2;

        var value = formData[key];
        var isString = isNaN(value) && typeof value === 'string';

        if (!isString || !isDateValid(value)) {
            continue;
        }

        parsed[key] = formatDateStringToISO(value, 'L', 'pt-br');
    }

    return parsed;
};

export var exportFormDataValeus = function exportFormDataValeus() {
    var formData = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var parsed = _extends({}, formData);

    for (var _iterator2 = Object.keys(formData), _isArray2 = Array.isArray(_iterator2), _i2 = 0, _iterator2 = _isArray2 ? _iterator2 : _iterator2[Symbol.iterator]();;) {
        var _ref3;

        if (_isArray2) {
            if (_i2 >= _iterator2.length) break;
            _ref3 = _iterator2[_i2++];
        } else {
            _i2 = _iterator2.next();
            if (_i2.done) break;
            _ref3 = _i2.value;
        }

        var key = _ref3;

        var value = formData[key];
        var isString = isNaN(value) && typeof value === 'string';

        if (!isString || !isDateValid(value)) {
            continue;
        }

        parsed[key] = toDateString(value);
    }

    return parsed;
};

==> form-dinamico-react-render-0.1.6.tgz: package/es/formTransformer.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import { alloweds, isTypeHasntLabel } from './utils/elementsUtils';
import { isDateValid, toDateString, formatDateStringToISO } from './utils/dateUtils';

export var formToJSONSchema = function formToJSONSchema() {
    var form = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var schema = {
        type: 'object',
        properties: {}
    };
    var _form$elements = form.elements,
        elements = _form$elements === undefined ? [] : _form$elements;


    return elements.reduce(function (newSchema, section) {
        var elements = section.elements;

        var sectionProperties = elements.filter(function (field) {
            return alloweds.includes(field.type);
        }).reduce(function (previousFields, field) {
            var key = field.key,
                title = field.title,
                type = field.type,
                titleMap = field.titleMap,
                mappingName = field.mappingName,
                mappingValue = field.mappingValue,
                operation = field.operation,
                service = field.service;


            previousFields[key] = { title: title, type: 'string', required: [], mappingName: mappingName, mappingValue: mappingValue, operation: operation, service: service };

            if (type === 'radios' && titleMap) {
                previousFields[key].enum = titleMap.map(function (object) {
                    return '' + object.value;
                });
                previousFields[key].enumNames = titleMap.map(function (object) {
                    return '' + object.name;
                });
            }

            if (type === 'checkboxes' && titleMap) {
                previousFields[key].type = 'array';
                previousFields[key].items = {
                    type: 'string',
                    'enum': titleMap.map(function (object) {
                        return '' + object.value;
                    }),
                    enumNames: titleMap.map(function (object) {
                        return '' + object.name;
                    })
                };
                previousFields[key].uniqueItems = true;
            }

            if (type === 'file-multiple') {
                previousFields[key].type = 'array';
                previousFields[key].items = {
                    type: 'object',
                    properties: {
                        name: { type: 'string' },
                        id: { type: 'string' },
                        type: { type: 'string' },
                        length: { type: 'number' },
                        originalFileName: { type: 'string' },
                        link: { type: 'string' },
                        displayName: { type: 'string' }
                    }
                };
            }

            if (type === 'select' && titleMap) {
                previousFields[key].items = {
                    type: 'array',
                    titleMap: titleMap
                };
            }

            if (type === 'table-editable') {
                previousFields[key].type = 'string';
                previousFields[key].elements = field.elements;
            }

            return previousFields;
        }, {});

        return _extends({}, newSchema, {
            properties: _extends({}, newSchema.properties, sectionProperties)
        });
    }, schema);
};

export var formToUISchema = function formToUISchema() {
    var form = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var environment = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var _form$elements2 = form.elements,
        elements = _form$elements2 === undefined ? [] : _form$elements2;


    return elements.reduce(function (uiSchema, section, indice) {
        var elements = section.elements;


        var schemaProperties = elements.filter(function (field) {
            return alloweds.includes(field.type);
        }).reduce(function (previousFields, field) {
            var key = field.key,
                type = field.type,
                cols = field.cols;

            var fieldProps = {};

            if (cols) {
                var _ref;

                var sectionLayoutArray = uiSchema['ui:layout'][indice] || [];
                uiSchema['ui:layout'][indice] = [].concat(sectionLayoutArray, [(_ref = {}, _ref[key] = Number(cols), _ref)]);
            }

            if (type === 'textarea') {
                fieldProps['ui:widget'] = 'textarea';
            }

            if (type === 'input-date') {
                fieldProps['ui:widget'] = 'dateWidget';
            }

            if (type === 'h1') {
                fieldProps['ui:widget'] = 'h1Widget';
            }

            if (type === 'radios') {
                fieldProps['ui:widget'] = 'radio';
            }

            if (type === 'checkboxes') {
                fieldProps['ui:widget'] = 'checkboxes';

                var uiOptions = fieldProps['ui:options'];
                fieldProps['ui:options'] = _extends({}, uiOptions, {
                    addable: false,
                    orderable: false,
                    removable: false
                });
            }

            if (type === 'file-multiple') {
                var upload = environment.upload;


                fieldProps['ui:widget'] = 'file-multiple';

                var _uiOptions = fieldProps['ui:options'];
                fieldProps['ui:options'] = _extends({}, _uiOptions, {
                    addable: false,
                    orderable: false,
                    removable: false,
                    upload: upload
                });
            }

            if (type === 'rich-text') {
                fieldProps['ui:widget'] = 'richTextWidget';
            }

            if (type === 'select') {
                fieldProps['ui:widget'] = 'select';
            }

            if (type === 'table-editable') {
                fieldProps['ui:widget'] = 'table-editable';
            }

            if (isTypeHasntLabel(type)) {
                var _uiOptions2 = fieldProps['ui:options'];
                fieldProps['ui:options'] = _extends({}, _uiOptions2, { label: false });
            }

            if (environment.customProps && environment.customProps[type]) {
                var customProps = environment.customProps[type];

                var _uiOptions3 = fieldProps['ui:options'];
                fieldProps['ui:options'] = _extends({}, _uiOptions3, {
                    customProps: customProps
                });
            }

            previousFields[key] = fieldProps;

            return previousFields;
        }, {});

        return _extends({}, uiSchema, schemaProperties);
    }, { 'ui:layout': [] });
};

export var formDefaultValues = function formDefaultValues() {
    var form = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var _form$elements3 = form.elements,
        elements = _form$elements3 === undefined ? [] : _form$elements3;


    return elements.reduce(function (newSchema, section) {
        var elements = section.elements;


        var schemaProperties = elements.reduce(function (previousFields, field) {
            var key = field.key,
                type = field.type,
                valueDefault = field.valueDefault;


            if (!valueDefault) {
                return previousFields;
            }

            var value = valueDefault;

            if (type === 'checkboxes') {
                value = valueDefault.split(',');
            }

            if (type === 'input-date') {
                value = formatDateStringToISO(valueDefault);
            }

            previousFields[key] = value;

            return previousFields;
        }, {});

        return _extends({}, newSchema, schemaProperties);
    }, {});
};

export var formDataValues = function formDataValues() {
    var formData = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var parsed = _extends({}, formData);

    for (var _iterator = Object.keys(formData), _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {
        var _ref2;

        if (_isArray) {
            if (_i >= _iterator.length) break;
            _ref2 = _iterator[_i++];
        } else {
            _i = _iterator.next();
            if (_i.done) break;
            _ref2 = _i.value;
        }

        var key = _ref2;

        var value = formData[key];
        var isString = isNaN(value) && typeof value === 'string';

        if (!isString || !isDateValid(value)) {
            continue;
        }

        parsed[key] = formatDateStringToISO(value, 'L', 'pt-br');
    }

    return parsed;
};

export var exportFormDataValeus = function exportFormDataValeus() {
    var formData = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var parsed = _extends({}, formData);

    for (var _iterator2 = Object.keys(formData), _isArray2 = Array.isArray(_iterator2), _i2 = 0, _iterator2 = _isArray2 ? _iterator2 : _iterator2[Symbol.iterator]();;) {
        var _ref3;

        if (_isArray2) {
            if (_i2 >= _iterator2.length) break;
            _ref3 = _iterator2[_i2++];
        } else {
            _i2 = _iterator2.next();
            if (_i2.done) break;
            _ref3 = _i2.value;
        }

        var key = _ref3;

        var value = formData[key];
        var isString = isNaN(value) && typeof value === 'string';

        if (!isString || !isDateValid(value)) {
            continue;
        }

        parsed[key] = toDateString(value);
    }

    return parsed;
};
